pub fn empty_extension_registry<C: Sync>() -> Arc<ExtensionRegistry<C>> ⓘExpand description
Creates an empty shared registry for hosts that do not register contributions.
pub fn empty_extension_registry<C: Sync>() -> Arc<ExtensionRegistry<C>> ⓘCreates an empty shared registry for hosts that do not register contributions.