pub struct ExtensionRegistryBuilder<C: Sync> { /* private fields */ }Expand description
Mutable registry used while hosts register typed runtime contributions.
Implementations
Sourceimpl<C: Sync> ExtensionRegistryBuilder<C>
impl<C: Sync> ExtensionRegistryBuilder<C>
Sourcepub fn with_event_sink(event_sink: Arc<dyn ExtensionEventSink>) -> Self
pub fn with_event_sink(event_sink: Arc<dyn ExtensionEventSink>) -> Self
Creates an empty registry builder with a host-provided event sink.
Sourcepub fn event_sink(&self) -> Arc<dyn ExtensionEventSink> ⓘ
pub fn event_sink(&self) -> Arc<dyn ExtensionEventSink> ⓘ
Returns the host event sink to pass into extension constructors.
Sourcepub fn approval_review_contributor(
&mut self,
contributor: Arc<dyn ApprovalReviewContributor>,
)
pub fn approval_review_contributor( &mut self, contributor: Arc<dyn ApprovalReviewContributor>, )
Registers one approval-review contributor.
Sourcepub fn thread_lifecycle_contributor(
&mut self,
contributor: Arc<dyn ThreadLifecycleContributor<C>>,
)
pub fn thread_lifecycle_contributor( &mut self, contributor: Arc<dyn ThreadLifecycleContributor<C>>, )
Registers one thread-lifecycle contributor.
Sourcepub fn turn_lifecycle_contributor(
&mut self,
contributor: Arc<dyn TurnLifecycleContributor>,
)
pub fn turn_lifecycle_contributor( &mut self, contributor: Arc<dyn TurnLifecycleContributor>, )
Registers one turn-lifecycle contributor.
Sourcepub fn config_contributor(&mut self, contributor: Arc<dyn ConfigContributor<C>>)
pub fn config_contributor(&mut self, contributor: Arc<dyn ConfigContributor<C>>)
Registers one config contributor.
Sourcepub fn token_usage_contributor(
&mut self,
contributor: Arc<dyn TokenUsageContributor>,
)
pub fn token_usage_contributor( &mut self, contributor: Arc<dyn TokenUsageContributor>, )
Registers one token-usage contributor.
Sourcepub fn skill_invocation_contributor(
&mut self,
contributor: Arc<dyn SkillInvocationContributor>,
)
pub fn skill_invocation_contributor( &mut self, contributor: Arc<dyn SkillInvocationContributor>, )
Registers one skill-invocation contributor.
Sourcepub fn prompt_contributor(&mut self, contributor: Arc<dyn ContextContributor>)
pub fn prompt_contributor(&mut self, contributor: Arc<dyn ContextContributor>)
Registers one prompt contributor.
Sourcepub fn mcp_server_contributor(
&mut self,
contributor: Arc<dyn McpServerContributor<C>>,
)
pub fn mcp_server_contributor( &mut self, contributor: Arc<dyn McpServerContributor<C>>, )
Registers one runtime MCP server contributor.
Sourcepub fn turn_input_contributor(
&mut self,
contributor: Arc<dyn TurnInputContributor>,
)
pub fn turn_input_contributor( &mut self, contributor: Arc<dyn TurnInputContributor>, )
Registers one turn-input contributor.
Sourcepub fn tool_contributor(&mut self, contributor: Arc<dyn ToolContributor>)
pub fn tool_contributor(&mut self, contributor: Arc<dyn ToolContributor>)
Registers one native tool contributor.
Sourcepub fn tool_lifecycle_contributor(
&mut self,
contributor: Arc<dyn ToolLifecycleContributor>,
)
pub fn tool_lifecycle_contributor( &mut self, contributor: Arc<dyn ToolLifecycleContributor>, )
Registers one tool-lifecycle contributor.
Sourcepub fn turn_item_contributor(
&mut self,
contributor: Arc<dyn TurnItemContributor>,
)
pub fn turn_item_contributor( &mut self, contributor: Arc<dyn TurnItemContributor>, )
Registers one ordered turn-item contributor.
Sourcepub fn build(self) -> ExtensionRegistry<C>
pub fn build(self) -> ExtensionRegistry<C>
Finishes construction and returns the immutable registry.