pub struct ExtensionTurnItem {
pub item: ExtensionItem,
pub legacy_events: Vec<EventMsg>,
}Expand description
Visible turn items that an extension may publish into the host lifecycle.
Fields
item: ExtensionItemCanonical extension item plus compatibility events derived by its owner.
Core intentionally does not inspect extension-owned payloads, so it cannot derive their legacy fanout. It emits the canonical lifecycle event first, then these extension-provided events. Core also skips global turn-item contributors here so extensions cannot mutate items owned by other extensions.
legacy_events: Vec<EventMsg>Trait Implementations
Sourceimpl Clone for ExtensionTurnItem
impl Clone for ExtensionTurnItem
Sourcefn clone(&self) -> ExtensionTurnItem
fn clone(&self) -> ExtensionTurnItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ExtensionTurnItem
impl RefUnwindSafe for ExtensionTurnItem
impl Send for ExtensionTurnItem
impl Sync for ExtensionTurnItem
impl Unpin for ExtensionTurnItem
impl UnsafeUnpin for ExtensionTurnItem
impl UnwindSafe for ExtensionTurnItem