pub struct McpServerContributionContext<'a, C> { /* private fields */ }Expand description
Input supplied while resolving MCP server contributions.
Thread-scoped implementations can read stable host inputs through Self::thread_init and
keep their cache in Self::thread_store. Implementations should not retain borrowed context
after contribution completes.
Implementations
Sourceimpl<'a, C> McpServerContributionContext<'a, C>
impl<'a, C> McpServerContributionContext<'a, C>
Sourcepub fn global(config: &'a C) -> Self
pub fn global(config: &'a C) -> Self
Creates context for resolution that is not associated with a running thread.
Sourcepub fn for_step(
config: &'a C,
thread_init: &'a ExtensionDataInit,
thread_store: &'a ExtensionData,
originator: &'a str,
ready_selected_capability_roots: &'a [SelectedCapabilityRoot],
executor_capability_discovery: Option<&'a ExecutorCapabilityDiscoverySnapshot>,
) -> Self
pub fn for_step( config: &'a C, thread_init: &'a ExtensionDataInit, thread_store: &'a ExtensionData, originator: &'a str, ready_selected_capability_roots: &'a [SelectedCapabilityRoot], executor_capability_discovery: Option<&'a ExecutorCapabilityDiscoverySnapshot>, ) -> Self
Creates context for one model step using only currently available environments.
Sourcepub fn thread_store(&self) -> Option<&'a ExtensionData>
pub fn thread_store(&self) -> Option<&'a ExtensionData>
Returns extension-owned state when resolving for a running thread.
Sourcepub fn thread_init(&self) -> Option<&'a ExtensionDataInit>
pub fn thread_init(&self) -> Option<&'a ExtensionDataInit>
Returns stable host inputs when resolving for a running thread.
Sourcepub fn originator(&self) -> Option<&'a str>
pub fn originator(&self) -> Option<&'a str>
Returns the effective request originator when resolving for a running thread.
Sourcepub fn ready_selected_capability_roots(
&self,
) -> Option<&'a [SelectedCapabilityRoot]>
pub fn ready_selected_capability_roots( &self, ) -> Option<&'a [SelectedCapabilityRoot]>
Returns selected roots resolved against the ready environments for this model step.
Sourcepub fn executor_capability_discovery(
&self,
) -> Option<&'a ExecutorCapabilityDiscoverySnapshot>
pub fn executor_capability_discovery( &self, ) -> Option<&'a ExecutorCapabilityDiscoverySnapshot>
Returns the executor-materialized capability files for this model step, when enabled.