pub struct WorldStateContributionInput<'a> {
pub thread_id: ThreadId,
pub turn_id: &'a str,
pub environments: &'a [TurnEnvironmentSelection],
pub ready_selected_capability_roots: &'a [SelectedCapabilityRoot],
pub executor_capability_discovery: Option<&'a ExecutorCapabilityDiscoverySnapshot>,
pub session_store: &'a ExtensionData,
pub thread_store: &'a ExtensionData,
pub turn_store: &'a ExtensionData,
pub step_store: &'a ExtensionData,
}Expand description
Host state available while an extension contributes one sampling step’s World State.
Fields
thread_id: ThreadIdturn_id: &'a strenvironments: &'a [TurnEnvironmentSelection]ready_selected_capability_roots: &'a [SelectedCapabilityRoot]Selected roots whose stable environments are ready in this sampling step.
executor_capability_discovery: Option<&'a ExecutorCapabilityDiscoverySnapshot>Executor-materialized capability files shared by all consumers in this exact step.
session_store: &'a ExtensionDatathread_store: &'a ExtensionDataturn_store: &'a ExtensionDatastep_store: &'a ExtensionDataHost capabilities bound to this exact sampling step.