ConfigContributor

Trait ConfigContributor 

pub trait ConfigContributor<C>: Send + Sync {
    // Provided method
    fn on_config_changed(
        &self,
        _session_store: &ExtensionData,
        _thread_store: &ExtensionData,
        _previous_config: &C,
        _new_config: &C,
    ) { ... }
}
Contributor for host-owned configuration changes.

Implementations should treat the supplied values as immutable before/after snapshots of the effective thread configuration.

Provided Methods

fn on_config_changed( &self, _session_store: &ExtensionData, _thread_store: &ExtensionData, _previous_config: &C, _new_config: &C, )

Called after the host commits a changed thread configuration.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors