ResponseItemInjector

Trait ResponseItemInjector 

pub trait ResponseItemInjector: Send + Sync {
    // Required method
    fn inject_response_items<'a>(
        &'a self,
        items: Vec<ResponseInputItem>,
    ) -> ResponseItemInjectionFuture<'a>;
}
Host-provided helper for extensions that need to steer the active model turn.

Implementations should inject the supplied response items into the active turn when one can accept same-turn model input. If injection is unavailable, they return the unchanged items to the caller.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors