UserInstructionsProvider

Trait UserInstructionsProvider 

pub trait UserInstructionsProvider: Send + Sync {
    // Required method
    fn load_user_instructions(&self) -> LoadUserInstructionsFuture<'_>;
}
Loads the user instructions that apply when a root thread runtime starts.

Implementations should return any recoverable loading problems as warnings while still returning usable fallback instructions when available.

Required Methods

fn load_user_instructions(&self) -> LoadUserInstructionsFuture<'_>

Loads the snapshot to use for a newly created root runtime.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors